caellion-python-commons: version-check Namespace Reference

caellion-python-commons

Variables
version-check Namespace Reference

## Variables
string | version = "0.0.0"
string | commitid = "0000000"
string | branch = "unknown"
bool | is_initial = False
bool | invalid_set_version = False
string | set_version_term = "set-version"
string | bump_minor_term = "bump-minor"
string | bump_major_term = "bump-major"
int | major = 0
int | minor = 0
int | patch = 0
| describe = sys.argv[1]
| commits = sys.argv[3]
| dsplit = describe.split("-")
| splits = describe.split("-")
string | version_split = version.split(".")
int | bump_by = 1
int | major_new = major
int | minor_new = minor
int | patch_new = patch
| vsubs = commit.split("[" + set_version_term)
| file
| major_ = int(vsubs[0])
| minor_ = int(vsubs[1])
| patch_ = int(vsubs[2])
string | version_tag = str(major) + "." + str(minor) + "." + str(patch) + str("-") + branch
string | version_short = str(major) + "." + str(minor) + "." + str(patch)
string | final_version = str(major) + "." + str(minor) + "." + str(patch) + "-" + branch + "-" + commitid
| contents = fp.read()

## Variable Documentation

## ◆ branch

version-check.branch = "unknown"

Definition at line 7 of file version-check.py.

## ◆ bump_by

int version-check.bump_by = 1

Definition at line 53 of file version-check.py.

## ◆ bump_major_term

string version-check.bump_major_term = "bump-major"

Definition at line 14 of file version-check.py.

## ◆ bump_minor_term

string version-check.bump_minor_term = "bump-minor"

Definition at line 13 of file version-check.py.

## ◆ commitid

version-check.commitid = "0000000"

Definition at line 6 of file version-check.py.

## ◆ commits

string version-check.commits = sys.argv[3]

Definition at line 24 of file version-check.py.

## ◆ contents

version-check.contents = fp.read()

Definition at line 152 of file version-check.py.

## ◆ describe

version-check.describe = sys.argv[1]

Definition at line 20 of file version-check.py.

## ◆ dsplit

version-check.dsplit = describe.split("-")

Definition at line 31 of file version-check.py.

## ◆ file

version-check.file

Definition at line 82 of file version-check.py.

## ◆ final_version

string version-check.final_version = str(major) + "." + str(minor) + "." + str(patch) + "-" + branch + "-" + commitid

Definition at line 147 of file version-check.py.

## ◆ invalid_set_version

bool version-check.invalid_set_version = False

Definition at line 10 of file version-check.py.

## ◆ is_initial

bool version-check.is_initial = False

Definition at line 9 of file version-check.py.

## ◆ major

int version-check.major = 0

Definition at line 16 of file version-check.py.

## ◆ major_

version-check.major_ = int(vsubs[0])

Definition at line 108 of file version-check.py.

## ◆ major_new

version-check.major_new = major

Definition at line 61 of file version-check.py.

## ◆ minor

int version-check.minor = 0

Definition at line 17 of file version-check.py.

## ◆ minor_

version-check.minor_ = int(vsubs[1])

Definition at line 109 of file version-check.py.

## ◆ minor_new

version-check.minor_new = minor

Definition at line 62 of file version-check.py.

## ◆ patch

int version-check.patch = 0

Definition at line 18 of file version-check.py.

## ◆ patch_

version-check.patch_ = int(vsubs[2])

Definition at line 110 of file version-check.py.

## ◆ patch_new

version-check.patch_new = patch

Definition at line 63 of file version-check.py.

## ◆ set_version_term

string version-check.set_version_term = "set-version"

Definition at line 12 of file version-check.py.

## ◆ splits

version-check.splits = describe.split("-")

Definition at line 34 of file version-check.py.

## ◆ version

version-check.version = "0.0.0"

Definition at line 5 of file version-check.py.

## ◆ version_short

string version-check.version_short = str(major) + "." + str(minor) + "." + str(patch)

Definition at line 146 of file version-check.py.

## ◆ version_split

string version-check.version_split = version.split(".")

Definition at line 37 of file version-check.py.

## ◆ version_tag

string version-check.version_tag = str(major) + "." + str(minor) + "." + str(patch) + str("-") + branch

Definition at line 145 of file version-check.py.

## ◆ vsubs

version-check.vsubs = commit.split("[" + set_version_term)

Definition at line 77 of file version-check.py.